@@ -10,16 +10,19 @@ from typing import List, Type
 from marshmallow import Schema, fields
 from marshmallow_jsonschema import JSONSchema  # type:ignore[import]
 
-from ahbicht.content_evaluation.categorized_key_extract import CategorizedKeyExtractSchema
-from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResultSchema
-from ahbicht.evaluation_results import (
+from ahbicht.json_serialization.tree_schema import TokenSchema  # , TreeSchema
+from ahbicht.models.categorized_key_extract import CategorizedKeyExtractSchema
+from ahbicht.models.condition_nodes import EvaluatedFormatConstraintSchema
+from ahbicht.models.content_evaluation_result import ContentEvaluationResultSchema
+from ahbicht.models.evaluation_results import (
     AhbExpressionEvaluationResultSchema,
     FormatConstraintEvaluationResultSchema,
     RequirementConstraintEvaluationResultSchema,
 )
-from ahbicht.expressions.condition_nodes import EvaluatedFormatConstraintSchema
-from ahbicht.json_serialization.tree_schema import TokenSchema  # , TreeSchema
-from ahbicht.mapping_results import ConditionKeyConditionTextMappingSchema, PackageKeyConditionExpressionMappingSchema
+from ahbicht.models.mapping_results import (
+    ConditionKeyConditionTextMappingSchema,
+    PackageKeyConditionExpressionMappingSchema,
+)
 
 schema_types: List[Type[Schema]] = [
     RequirementConstraintEvaluationResultSchema,
