@@ -9,12 +9,12 @@ seems like a big overhead. The code representation of "all outcomes are already
 ContentEvaluationResult. Now the methods below are useful. Simply provide a content evaluation result (the data) and
 the evaluators are created based on the already known outcomes. You do not have to actually touch any evaluator code.
 """
+
 from typing import Callable, Iterable, Optional, Protocol, Tuple
 
 import inject
-from maus.edifact import EdifactFormat, EdifactFormatVersion
+from efoli import EdifactFormat, EdifactFormatVersion
 
-from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluatableDataProvider
 from ahbicht.content_evaluation.fc_evaluators import (
     ContentEvaluationResultBasedFcEvaluator,
@@ -37,6 +37,7 @@ from ahbicht.expressions.package_expansion import (
     DictBasedPackageResolver,
     PackageResolver,
 )
+from ahbicht.models.content_evaluation_result import ContentEvaluationResult
 
 
 # pylint:disable=too-few-public-methods
