@@ -4,15 +4,16 @@ Typical use-cases are for example
 * you must only provide a Gerätenummer if the Transaktionsgrund is e.g. 'E08'
 * you must only provide an Ausbaudatum if the meter is being removed e.g. 'Z02'
 """
+
 import asyncio
 import inspect
 from abc import ABC, abstractmethod
 from typing import Dict, List, Optional
 
-from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluationContext
 from ahbicht.content_evaluation.evaluators import Evaluator
-from ahbicht.expressions.condition_nodes import ConditionFulfilledValue
+from ahbicht.models.condition_nodes import ConditionFulfilledValue
+from ahbicht.models.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
 
 
 class RcEvaluator(Evaluator, ABC):
@@ -130,7 +131,7 @@ class ContentEvaluationResultBasedRcEvaluator(RcEvaluator):
     async def evaluate_single_condition(
         self, condition_key: str, evaluatable_data: EvaluatableData, context: Optional[EvaluationContext] = None
     ) -> ConditionFulfilledValue:
-        content_evaluation_result: ContentEvaluationResult = self._schema.load(evaluatable_data.edifact_seed)
+        content_evaluation_result: ContentEvaluationResult = self._schema.load(evaluatable_data.body)
         try:
             return content_evaluation_result.requirement_constraints[condition_key]
         except KeyError as key_error:
