@@ -4,19 +4,20 @@ The AhbExpressionTransformer defines the rules how the different parts of the pa
 
 The used terms are defined in the README.md.
 """
+
 from typing import Awaitable, Dict, List, Union
 
 from lark import Token, Transformer, Tree, v_args
 from lark.exceptions import VisitError
 
-from ahbicht.evaluation_results import (
+from ahbicht.expressions.format_constraint_expression_evaluation import format_constraint_evaluation
+from ahbicht.expressions.requirement_constraint_expression_evaluation import requirement_constraint_evaluation
+from ahbicht.models.enums import ModalMark, PrefixOperator, RequirementIndicator
+from ahbicht.models.evaluation_results import (
     AhbExpressionEvaluationResult,
     FormatConstraintEvaluationResult,
     RequirementConstraintEvaluationResult,
 )
-from ahbicht.expressions.enums import ModalMark, PrefixOperator, RequirementIndicator
-from ahbicht.expressions.format_constraint_expression_evaluation import format_constraint_evaluation
-from ahbicht.expressions.requirement_constraint_expression_evaluation import requirement_constraint_evaluation
 from ahbicht.utility_functions import gather_if_necessary
 
 _str_to_modal_mark_mapping: Dict[str, ModalMark] = {
@@ -35,7 +36,7 @@ class AhbExpressionTransformer(Transformer):
     """
     Transformer, that evaluates the trees built from the ahb expressions.
     The input are the conditions as defined in the AHBs in the form of ConditionNodes.
-    It returns a list of the seperated requirement indicators with
+    It returns a list of the separated requirement indicators with
     their respective condition expressions already evaluated to booleans.
     """
 
@@ -63,7 +64,7 @@ class AhbExpressionTransformer(Transformer):
     ) -> Awaitable[AhbExpressionEvaluationResult]:
         """
         Evaluates the condition expression of the respective requirement indicator expression and returns a list of the
-        seperated requirement indicators with their results of the condition check.
+        separated requirement indicators with their results of the condition check.
         """
         return self._single_requirement_indicator_expression_async(requirement_indicator, condition_expression)
 
