@@ -1,9 +1,10 @@
 """
-This module parses a condition expression like "[59] U ([123] O [456])" into a tree structur using
+This module parses a condition expression like "[59] U ([123] O [456])" into a tree structure using
 the parsing library lark: https://lark-parser.readthedocs.io/en/latest/
 
 The used terms are defined in the README_conditions.md.
 """
+
 # pylint:disable=cyclic-import
 from functools import lru_cache
 from typing import List, Union
@@ -11,14 +12,17 @@ from typing import List, Union
 from lark import Lark, Token, Tree
 from lark.exceptions import UnexpectedCharacters, UnexpectedEOF
 
-from ahbicht.condition_node_distinction import ConditionNodeType, derive_condition_node_type
-from ahbicht.content_evaluation.categorized_key_extract import CategorizedKeyExtract
+from ahbicht.condition_node_distinction import derive_condition_node_type
 from ahbicht.expressions import parsing_logger
+from ahbicht.expressions.sanitizer import sanitize_expression
+from ahbicht.models.categorized_key_extract import CategorizedKeyExtract
+from ahbicht.models.condition_node_type import ConditionNodeType
 from ahbicht.utility_functions import tree_copy
 
 GRAMMAR = r"""
 ?expression: expression "O"i expression -> or_composition
-            | expression "∨" expression -> or_composition
+            | expression "∨" expression -> or_composition // the logical or
+            | expression "V"i expression -> or_composition // a 'v' for those who first chose to introduce logical symbols like ∨ but now can't find them on their keyboard  
             | expression "X"i expression -> xor_composition
             | expression "⊻" expression -> xor_composition
             | expression "U"i expression -> and_composition
@@ -34,7 +38,7 @@ package: "[" PACKAGE_KEY REPEATABILITY? "]" // a rule for packages
 condition: "[" CONDITION_KEY "]" // a rule for condition keys
 TIME_CONDITION_KEY: /UB(1|2|3)/ // a terminal for "übergreifende Bedingungen für Zeitpunktangaben"
 CONDITION_KEY: INT // a TERMINAL for all the remaining ints (lower priority)
-REPEATABILITY: /\d+\.{2}[1-9]\d*/ // a terminal for repetitions n..m with n>=0 and m>n
+REPEATABILITY: /\d+\.{2}(?:([1-9]\d*)|n)/ // a terminal for repetitions n..m with n>=0 and m>n or m=="n"
 PACKAGE_KEY: INT "P" // a TERMINAL for all INTs followed by "P" (high priority)
 %import common.INT
 %import common.WS
@@ -57,6 +61,7 @@ def parse_condition_expression_to_tree(condition_expression: str) -> Tree[Token]
     :return parsed_tree: Tree
     """
     try:
+        condition_expression = sanitize_expression(condition_expression)
         parsed_tree = _parser.parse(condition_expression)
         parsing_logger.debug("Successfully parsed '%s' as condition expression", condition_expression)
     except (UnexpectedEOF, UnexpectedCharacters, TypeError) as eof:
@@ -64,7 +69,9 @@ def parse_condition_expression_to_tree(condition_expression: str) -> Tree[Token]
             "The condition expression is syntactically incorrect: '%s'", condition_expression, exc_info=eof
         )
         raise SyntaxError(
-            """Please make sure that:
+            f"""
+            condition expression: {condition_expression}
+            Please make sure that:
              * all conditions have the form [INT]
              * all packages have the form [INTPn..m]
              * no conditions are empty
@@ -84,26 +91,30 @@ def extract_categorized_keys_from_tree(
     See 'Allgemeine Festlegungen' from EDI@Energy.
     """
     result = CategorizedKeyExtract(
-        format_constraint_keys=[], requirement_constraint_keys=[], hint_keys=[], package_keys=[], time_condition_keys=[]
+        format_constraint_keys=[],
+        requirement_constraint_keys=[],
+        hint_keys=[],
+        package_keys=[],
+        time_condition_keys=[],
     )
     condition_keys: List[str]
     if isinstance(tree_or_list, list):
         condition_keys = tree_or_list
     elif isinstance(tree_or_list, Tree):
         condition_keys = [
-            x.value  # type:ignore[attr-defined]
+            x.value
             for x in tree_or_list.scan_values(
                 lambda token: token.type == "CONDITION_KEY"  # type:ignore[union-attr]
             )
         ]
         result.package_keys = [
-            x.value  # type:ignore[attr-defined]
+            x.value
             for x in tree_or_list.scan_values(
                 lambda token: token.type == "PACKAGE_KEY"  # type:ignore[union-attr]
             )
         ]
         result.time_condition_keys = [
-            x.value  # type:ignore[attr-defined]
+            x.value
             for x in tree_or_list.scan_values(
                 lambda token: token.type == "TIME_CONDITION_KEY"  # type:ignore[union-attr]
             )
@@ -115,6 +126,7 @@ def extract_categorized_keys_from_tree(
         if (
             condition_node_type is ConditionNodeType.REQUIREMENT_CONSTRAINT
             or condition_node_type is ConditionNodeType.REPEATABILITY_CONSTRAINT
+            or condition_node_type is ConditionNodeType.PACKAGE_REPEATABILITY
         ):
             result.requirement_constraint_keys.append(condition_key)
         elif condition_node_type is ConditionNodeType.HINT:
@@ -131,7 +143,10 @@ def extract_categorized_keys_from_tree(
 
 
 async def extract_categorized_keys(
-    condition_expression: str, resolve_packages: bool = False, replace_time_conditions: bool = False
+    condition_expression: str,
+    resolve_packages: bool = False,
+    resolve_time_conditions: bool = False,
+    replace_time_conditions: bool = False,
 ) -> CategorizedKeyExtract:
     """
     Parses the given condition expression and returns CategorizedKeyExtract as a template for content
@@ -144,6 +159,9 @@ async def extract_categorized_keys(
     from ahbicht.expressions.expression_resolver import parse_expression_including_unresolved_subexpressions
 
     tree = await parse_expression_including_unresolved_subexpressions(
-        condition_expression, resolve_packages=resolve_packages, replace_time_conditions=replace_time_conditions
+        condition_expression,
+        resolve_packages=resolve_packages,
+        resolve_time_conditions=resolve_time_conditions,
+        replace_time_conditions=replace_time_conditions,
     )
     return extract_categorized_keys_from_tree(tree, sanitize=True)
