@@ -1,11 +1,12 @@
 """
 Module to create expressions from scratch.
 """
+
 import re
 from abc import ABC, abstractmethod
 from typing import Generic, Optional, Protocol, Type, TypeVar, Union
 
-from ahbicht.expressions.condition_nodes import (
+from ahbicht.models.condition_nodes import (
     ConditionNode,
     EvaluatedComposition,
     EvaluatedFormatConstraint,
@@ -13,7 +14,7 @@ from ahbicht.expressions.condition_nodes import (
     RequirementConstraint,
     UnevaluatedFormatConstraint,
 )
-from ahbicht.expressions.enums import LogicalOperator
+from ahbicht.models.enums import LogicalOperator
 
 SupportedNodes = TypeVar("SupportedNodes")
 
@@ -61,18 +62,18 @@ class ExpressionBuilder(Generic[SupportedNodes], ABC):
         raise NotImplementedError("Has to be implemented by inheriting class.")
 
 
-TEffectiveFCExpressionBuilderArguments = Union[
+TEffectiveFCExpressionBuilderArguments = Union[  # pylint:disable=invalid-name
     EvaluatedComposition, UnevaluatedFormatConstraint, Optional[str]
 ]  # node types that have an effect on the built format constraint expression
 
-TUneffectiveFCExpressionBuilderArguments = Union[
+TUneffectiveFCExpressionBuilderArguments = Union[  # pylint:disable=invalid-name
     RequirementConstraint, EvaluatedComposition, Hint, Type[ConditionNode]
 ]  # node types that are formally accepted as argument but don't
 # have any effect. Instead of checking which nodes contain format constraints all are put into the
 # FormatConstraintExpressionBuilder, but it only has an effect on those with format constraints.
 # Note that EvaluatedComposition is in both classes since they can have format constraints but don't have to.
 
-TSupportedFCExpressionBuilderArguments = Union[
+TSupportedFCExpressionBuilderArguments = Union[  # pylint:disable=invalid-name
     TEffectiveFCExpressionBuilderArguments, TUneffectiveFCExpressionBuilderArguments
 ]
 
@@ -162,10 +163,10 @@ class _ClassesWithHintAttribute(Protocol):
     hint: str
 
 
-ClassesWithHintAttribute_co = TypeVar("ClassesWithHintAttribute_co", bound=_ClassesWithHintAttribute, covariant=True)
+ClassesWithHintAttribute = TypeVar("ClassesWithHintAttribute", bound=_ClassesWithHintAttribute)
 
 
-class HintExpressionBuilder(ExpressionBuilder[ClassesWithHintAttribute_co]):
+class HintExpressionBuilder(ExpressionBuilder[ClassesWithHintAttribute]):
     """
     Allows connecting hints with logical operations.
     """
