@@ -15,11 +15,11 @@ from lark.exceptions import VisitError
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluatableDataProvider
 from ahbicht.content_evaluation.fc_evaluators import FcEvaluator
 from ahbicht.content_evaluation.token_logic_provider import TokenLogicProvider
-from ahbicht.evaluation_results import FormatConstraintEvaluationResult
 from ahbicht.expressions.base_transformer import BaseTransformer
 from ahbicht.expressions.condition_expression_parser import parse_condition_expression_to_tree
-from ahbicht.expressions.condition_nodes import EvaluatedFormatConstraint
 from ahbicht.expressions.expression_builder import FormatErrorMessageExpressionBuilder
+from ahbicht.models.condition_nodes import EvaluatedFormatConstraint
+from ahbicht.models.evaluation_results import FormatConstraintEvaluationResult
 
 
 @v_args(inline=True)  # Children are provided as *args instead of a list argument
@@ -102,12 +102,12 @@ async def format_constraint_evaluation(
     else:
         parsed_tree_fc: Tree = parse_condition_expression_to_tree(format_constraints_expression)
         all_evaluatable_format_constraint_keys: List[str] = [
-            t.value for t in parsed_tree_fc.scan_values(lambda v: isinstance(v, Token))  # type:ignore[attr-defined]
+            t.value for t in parsed_tree_fc.scan_values(lambda v: isinstance(v, Token))
         ]
-        input_values: Dict[
-            str, EvaluatedFormatConstraint
-        ] = await _build_evaluated_format_constraint_nodes(  # pylint:disable=no-value-for-parameter
-            all_evaluatable_format_constraint_keys
+        input_values: Dict[str, EvaluatedFormatConstraint] = (
+            await _build_evaluated_format_constraint_nodes(  # pylint:disable=no-value-for-parameter
+                all_evaluatable_format_constraint_keys
+            )
         )
         resulting_evaluated_format_constraint_node: EvaluatedFormatConstraint = evaluate_format_constraint_tree(
             parsed_tree_fc, input_values
