@@ -2,6 +2,7 @@
 Package Expansion is the process of finding the condition expression which was abbreviated by using a package.
 e.g. if inside a tree "[123P]" is replaced by "[1] U ([2] O [3])".
 """
+
 import json
 import logging
 from abc import ABC, abstractmethod
@@ -9,11 +10,14 @@ from pathlib import Path
 from typing import Dict, List, Mapping, Optional
 
 import inject
-from maus.edifact import EdifactFormat, EdifactFormatVersion
+from efoli import EdifactFormat, EdifactFormatVersion
 
-from ahbicht.content_evaluation.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
 from ahbicht.content_evaluation.evaluationdatatypes import EvaluatableData, EvaluatableDataProvider
-from ahbicht.mapping_results import PackageKeyConditionExpressionMapping, PackageKeyConditionExpressionMappingSchema
+from ahbicht.models.content_evaluation_result import ContentEvaluationResult, ContentEvaluationResultSchema
+from ahbicht.models.mapping_results import (
+    PackageKeyConditionExpressionMapping,
+    PackageKeyConditionExpressionMappingSchema,
+)
 
 
 # pylint:disable=too-few-public-methods
