@@ -6,17 +6,17 @@ of the condition expression tree are handled.
 The used terms are defined in the README_conditions.md.
 """
 
-from typing import List, Literal, Mapping, Type, Union
+from typing import List, Literal, Mapping, Optional, Type, Union
 
 from lark import Token, Tree, v_args
 from lark.exceptions import VisitError
 
 from ahbicht.condition_node_builder import ConditionNodeBuilder, TRCTransformerArgument
-from ahbicht.evaluation_results import RequirementConstraintEvaluationResult
 from ahbicht.expressions import InvalidExpressionError
 from ahbicht.expressions.base_transformer import BaseTransformer
 from ahbicht.expressions.condition_expression_parser import parse_condition_expression_to_tree
-from ahbicht.expressions.condition_nodes import (
+from ahbicht.expressions.expression_builder import FormatConstraintExpressionBuilder, HintExpressionBuilder
+from ahbicht.models.condition_nodes import (
     ConditionFulfilledValue,
     ConditionNode,
     EvaluatedComposition,
@@ -25,7 +25,7 @@ from ahbicht.expressions.condition_nodes import (
     RequirementConstraint,
     UnevaluatedFormatConstraint,
 )
-from ahbicht.expressions.expression_builder import FormatConstraintExpressionBuilder, HintExpressionBuilder
+from ahbicht.models.evaluation_results import RequirementConstraintEvaluationResult
 
 
 @v_args(inline=True)  # Children are provided as *args instead of a list argument
@@ -121,6 +121,7 @@ class RequirementConstraintTransformer(BaseTransformer[TRCTransformerArgument, E
         elif composition == "xor_composition":
             resulting_conditions_fulfilled = left.conditions_fulfilled ^ right.conditions_fulfilled
         # resulting_conditions_fulfilled is never referenced before assignment when you obey the type hint
+        # pylint:disable=possibly-used-before-assignment
         evaluated_composition = EvaluatedComposition(conditions_fulfilled=resulting_conditions_fulfilled)
         return evaluated_composition
 
@@ -242,7 +243,7 @@ of the type RequirementConstraint, Hint or FormatConstraint."""
 
 
 async def requirement_constraint_evaluation(
-    condition_expression: Union[str, Tree]
+    condition_expression: Union[str, Tree],
 ) -> RequirementConstraintEvaluationResult:
     """
     Evaluation of the condition expression in regard to the requirement conditions (rc).
@@ -255,31 +256,30 @@ async def requirement_constraint_evaluation(
         parsed_tree_rc = condition_expression
 
     # get all condition keys from tree
-    all_condition_keys: List[str] = [
-        t.value for t in parsed_tree_rc.scan_values(lambda v: isinstance(v, Token))  # type: ignore[attr-defined]
-    ]
+    all_condition_keys: List[str] = [t.value for t in parsed_tree_rc.scan_values(lambda v: isinstance(v, Token))]
     condition_node_builder = ConditionNodeBuilder(all_condition_keys)
     input_nodes = await condition_node_builder.requirement_content_evaluation_for_all_condition_keys()
 
     resulting_condition_node: EvaluatedComposition = evaluate_requirement_constraint_tree(parsed_tree_rc, input_nodes)
 
-    requirement_constraints_fulfilled: bool = (
+    requirement_constraints_fulfilled: Optional[bool] = (
         resulting_condition_node.conditions_fulfilled == ConditionFulfilledValue.FULFILLED
     )
-    requirement_is_conditional = True
+    requirement_is_conditional: Optional[bool] = True
     if resulting_condition_node.conditions_fulfilled == ConditionFulfilledValue.NEUTRAL:  # pylint:disable=no-member
         requirement_constraints_fulfilled = True
         requirement_is_conditional = False
     if resulting_condition_node.conditions_fulfilled == ConditionFulfilledValue.UNKNOWN:  # pylint:disable=no-member
-        unknown_keys = [
-            node_key
-            for node_key, node_value in input_nodes.items()
-            if isinstance(node_value, RequirementConstraint)
-            and node_value.conditions_fulfilled == ConditionFulfilledValue.UNKNOWN
-        ]
-        raise NotImplementedError(
-            f"It is unknown if the conditions ({','.join(unknown_keys)}) are fulfilled due to missing information."
-        )
+        # unknown_keys = [
+        #    node_key
+        #    for node_key, node_value in input_nodes.items()
+        #    if isinstance(node_value, RequirementConstraint)
+        #    and node_value.conditions_fulfilled == ConditionFulfilledValue.UNKNOWN
+        # ]
+        # a NotImplementedError was raised here in ahbicht<=v0.5.11
+        # https://github.com/Hochfrequenz/ahbicht/issues/275
+        requirement_constraints_fulfilled = None
+        requirement_is_conditional = None
 
     format_constraints_expression = getattr(resulting_condition_node, "format_constraints_expression", None)
     if isinstance(resulting_condition_node, UnevaluatedFormatConstraint):
